@@ -4,8 +4,8 @@ import boto3
 
 def get_ncf_ranked_offers(rbi_cognito_id, table_name, access_key, secret_key):
     my_config = Config(region_name='us-east-1', connect_timeout=2, read_timeout=2, retries={'max_attempts': 2})
-    dynamodb = boto3.resource('dynamodb', config=my_config
-                              , aws_access_key_id=access_key, aws_secret_access_key=secret_key)
+    dynamodb = boto3.resource('dynamodb', config=my_config,
+                              aws_access_key_id=access_key, aws_secret_access_key=secret_key)
     ncf_pred_table = dynamodb.Table(table_name)
     try:
         response = ncf_pred_table.get_item(Key={'rbi_cognito_id': rbi_cognito_id})
